@@ -14,8 +14,7 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsHashRefWithData IsString IsStringWithData);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.24 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -477,9 +476,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.24 $ $Date: 2012-11-20 14:28:15 $
-
-=cut
