@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/GenericInterface/Transport/HTTP/Test.pm - GenericInterface network transport interface for testing
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::GenericInterface::Transport::HTTP::Test;
@@ -15,25 +16,45 @@ use HTTP::Request::Common;
 use LWP::UserAgent;
 use LWP::Protocol;
 
-# prevent 'Used once' warning for Kernel::OM
-use Kernel::System::ObjectManager;
+use Kernel::System::Web::Request;
 
-our $ObjectManagerDisabled = 1;
+use vars qw(@ISA);
 
 =head1 NAME
 
-Kernel::GenericInterface::Transport::HTTP::Test - GenericInterface network transport interface for testing purposes
+Kernel::GenericInterface::Transport::Test - GenericInterface network transport interface for testing purposes
+
+=head1 SYNOPSIS
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=item new()
 
 usually, you want to create an instance of this
 by using Kernel::GenericInterface::Transport->new();
 
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
     use Kernel::GenericInterface::Transport;
 
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
     my $TransportObject = Kernel::GenericInterface::Transport->new(
+        ConfigObject       => $ConfigObject,
+        LogObject          => $LogObject,
+        DBObject           => $DBObject,
+        MainObject         => $MainObject,
+        TimeObject         => $TimeObject,
+        EncodeObject       => $EncodeObject,
 
         TransportConfig => {
             Type => 'HTTP::Test',
@@ -56,7 +77,10 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    for my $Needed (qw( DebuggerObject TransportConfig)) {
+    for my $Needed (
+        qw(LogObject EncodeObject ConfigObject MainObject DebuggerObject TransportConfig)
+        )
+    {
         $Self->{$Needed} = $Param{$Needed} || return {
             Success      => 0,
             ErrorMessage => "Got no $Needed!"
@@ -66,7 +90,7 @@ sub new {
     return $Self;
 }
 
-=head2 ProviderProcessRequest()
+=item ProviderProcessRequest()
 
 this will read the incoming HTTP request via CGI and
 return the HTTP parameters in the data hash.
@@ -77,7 +101,6 @@ sub ProviderProcessRequest {
     my ( $Self, %Param ) = @_;
 
     if ( $Self->{TransportConfig}->{Config}->{Fail} ) {
-
         return {
             Success      => 0,
             ErrorMessage => "HTTP status code: 500",
@@ -85,7 +108,7 @@ sub ProviderProcessRequest {
         };
     }
 
-    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $ParamObject = Kernel::System::Web::Request->new( %{$Self} );
 
     my %Result;
     for my $ParamName ( $ParamObject->GetParamNames() ) {
@@ -98,7 +121,6 @@ sub ProviderProcessRequest {
     }
 
     if ( !%Result ) {
-
         return $Self->{DebuggerObject}->Error(
             Summary => 'No request data found.',
         );
@@ -111,7 +133,7 @@ sub ProviderProcessRequest {
     };
 }
 
-=head2 ProviderGenerateResponse()
+=item ProviderGenerateResponse()
 
 this will generate a query string from the passed data hash
 and generate an HTTP response with this string as the body.
@@ -124,7 +146,6 @@ sub ProviderGenerateResponse {
     my ( $Self, %Param ) = @_;
 
     if ( $Self->{TransportConfig}->{Config}->{Fail} ) {
-
         return {
             Success      => 0,
             ErrorMessage => 'Test response generation failed',
@@ -134,7 +155,8 @@ sub ProviderGenerateResponse {
     my $Response;
 
     if ( !$Param{Success} ) {
-        $Response = HTTP::Response->new( 500 => ( $Param{ErrorMessage} || 'Internal Server Error' ) );
+        $Response
+            = HTTP::Response->new( 500 => ( $Param{ErrorMessage} || 'Internal Server Error' ) );
         $Response->protocol('HTTP/1.0');
         $Response->content_type("text/plain; charset=UTF-8");
         $Response->date(time);
@@ -142,7 +164,8 @@ sub ProviderGenerateResponse {
     else {
 
         # generate a request string from the data
-        my $Request = HTTP::Request::Common::POST( 'http://testhost.local/', Content => $Param{Data} );
+        my $Request
+            = HTTP::Request::Common::POST( 'http://testhost.local/', Content => $Param{Data} );
 
         $Response = HTTP::Response->new( 200 => "OK" );
         $Response->protocol('HTTP/1.0');
@@ -164,7 +187,7 @@ sub ProviderGenerateResponse {
     };
 }
 
-=head2 RequesterPerformRequest()
+=item RequesterPerformRequest()
 
 in Fail mode, returns error status. Otherwise, returns the
 query string generated out of the data for the HTTP response.
@@ -191,7 +214,6 @@ sub RequesterPerformRequest {
     my ( $Self, %Param ) = @_;
 
     if ( $Self->{TransportConfig}->{Config}->{Fail} ) {
-
         return {
             Success      => 0,
             ErrorMessage => "HTTP status code: 500",
@@ -204,7 +226,7 @@ sub RequesterPerformRequest {
         testhttp => 'Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol'
     );
     my $UserAgent = LWP::UserAgent->new();
-    my $Response  = $UserAgent->post( 'testhttp://localhost.local/', Content => $Param{Data} );
+    my $Response = $UserAgent->post( 'testhttp://localhost.local/', Content => $Param{Data} );
 
     return {
         Success => 1,
@@ -214,6 +236,8 @@ sub RequesterPerformRequest {
     };
 }
 
+=back
+
 =begin Internal:
 
 =cut
@@ -222,7 +246,7 @@ sub RequesterPerformRequest {
 
 Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 This package is used to handle the custom HTTP requests of
 Kernel::GenericInterface::Transport::HTTP::Test.
@@ -231,9 +255,9 @@ sending them out to the network.
 
 =cut
 
-package Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol;    ## no critic
+package Kernel::GenericInterface::Transport::HTTP::Test::CustomHTTPProtocol;
 
-use parent qw(LWP::Protocol);
+use base qw(LWP::Protocol);
 
 sub new {
     my $Class = shift;
@@ -241,7 +265,7 @@ sub new {
     return $Class->SUPER::new(@_);
 }
 
-sub request {                                                                   ## no critic
+sub request {    ## no critic
     my $Self = shift;
 
     my ( $Request, $Proxy, $Arg, $Size, $Timeout ) = @_;
@@ -264,10 +288,10 @@ sub request {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
