@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminQueueAutoResponse.pm - to add/update/delete QueueAutoResponses
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminQueueAutoResponse.pm,v 1.35 2011/12/23 14:22:03 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +15,6 @@ use warnings;
 use Kernel::System::AutoResponse;
 use Kernel::System::Queue;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.35 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -74,7 +69,7 @@ sub Run {
                 ActionHome => 'AdminQueue',
             },
         );
-        for my $TypeID ( keys %TypeResponsesData ) {
+        for my $TypeID ( sort keys %TypeResponsesData ) {
             my %Data = $Self->{DBObject}->GetTableData(
                 Table => 'auto_response ar, auto_response_type art',
                 What  => 'ar.id, ar.name',
@@ -122,7 +117,7 @@ sub Run {
         my %TypeResponsesData = $Self->{AutoResponseObject}->AutoResponseTypeList();
 
         # Set Autoresponses IDs for this queue.
-        for my $TypeID ( keys %TypeResponsesData ) {
+        for my $TypeID ( sort keys %TypeResponsesData ) {
             push( @NewIDs, $Self->{ParamObject}->GetParam( Param => "IDs_$TypeID" ) );
         }
 
