@@ -1,8 +1,6 @@
 # --
 # Kernel/System/DynamicField/Backend/Dropdown.pm - Delegate for DynamicField Dropdown backend
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Dropdown.pm,v 1.63 2012/04/02 11:46:35 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,9 +16,6 @@ use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.63 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField::Backend::Dropdown
@@ -237,6 +232,17 @@ sub EditFieldRender {
         $FieldPossibleNone = $FieldConfig->{PossibleNone} || 0;
     }
 
+    my $Size = 1;
+
+    # TODO change ConfirmationNeeded parameter name to something more generic
+
+    # when ConfimationNeeded parameter is present (AdminGenericAgent) the filed should be displayed
+    # as an open list, because you might not want to change the value, otherwise a value will be
+    # selected
+    if ( $Param{ConfirmationNeeded} ) {
+        $Size = 5;
+    }
+
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data => $SelectionData || {},
         Name => $FieldName,
@@ -244,6 +250,7 @@ sub EditFieldRender {
         Translation  => $FieldConfig->{TranslatableValues} || 0,
         PossibleNone => $FieldPossibleNone,
         Class        => $FieldClass,
+        Size         => $Size,
         HTMLQuote    => 1,
     );
 
@@ -308,25 +315,6 @@ EOF
 EOF
     }
 
-    if ( $Param{SubmitOnChange} ) {
-
-        my $FieldSelector = '#' . $FieldName;
-
-        #add js to disable validation and do submit()
-        $HTMLString .= <<"EOF";
-<!--dtl:js_on_document_complete-->
-<script type="text/javascript">//<![CDATA[
-    \$('$FieldSelector').bind('change', function (Event) {
-        // make sure the ticket is not yet created on queue change
-        \$('input#Expand').val(1);
-        Core.Form.Validate.DisableValidation(\$(this).closest('form'));
-        \$(this).closest('form').submit();
-    });
-//]]></script>
-<!--dtl:js_on_document_complete-->
-EOF
-    }
-
     # call EditLabelRender on the common backend
     my $LabelString = $Self->{BackendCommonObject}->EditLabelRender(
         DynamicFieldConfig => $Param{DynamicFieldConfig},
@@ -524,7 +512,7 @@ sub SearchFieldRender {
 
     # add historic values to current values (if they don't exist anymore)
     if ( IsHashRefWithData($HistoricalValues) ) {
-        for my $Key ( keys %{$HistoricalValues} ) {
+        for my $Key ( sort keys %{$HistoricalValues} ) {
             if ( !$SelectionData->{$Key} ) {
                 $SelectionData->{$Key} = $HistoricalValues->{$Key}
             }
@@ -567,8 +555,9 @@ sub SearchFieldValueGet {
 
     # get dynamic field value form param object
     if ( defined $Param{ParamObject} ) {
-        my @FieldValues = $Param{ParamObject}
-            ->GetArray( Param => 'Search_DynamicField_' . $Param{DynamicFieldConfig}->{Name} );
+        my @FieldValues = $Param{ParamObject}->GetArray(
+            Param => 'Search_DynamicField_' . $Param{DynamicFieldConfig}->{Name}
+        );
 
         $Value = \@FieldValues;
     }
@@ -655,7 +644,7 @@ sub StatsFieldParameterBuild {
     );
 
     # add historic values to current values (if they don't exist anymore)
-    for my $Key ( keys %{$HistoricalValues} ) {
+    for my $Key ( sort keys %{$HistoricalValues} ) {
         if ( !$Values->{$Key} ) {
             $Values->{$Key} = $HistoricalValues->{$Key}
         }
@@ -801,7 +790,7 @@ sub AJAXPossibleValuesGet {
         );
     }
 
-    # retrun the possible values hash as a reference
+    # return the possible values hash as a reference
     return \%PossibleValues;
 }
 
@@ -814,10 +803,42 @@ sub HistoricalValuesGet {
         ValueType => 'Text',
     );
 
-    # retrun the historical values from database
+    # return the historical values from database
     return $HistoricalValues;
 }
 
+sub ValueLookup {
+    my ( $Self, %Param ) = @_;
+
+    my $Value = defined $Param{Key} ? $Param{Key} : '';
+
+    # get real values
+    my $PossibleValues = $Param{DynamicFieldConfig}->{Config}->{PossibleValues};
+
+    if ($Value) {
+
+        # check if there is a real value for this key (otherwise keep the key)
+        if ( $Param{DynamicFieldConfig}->{Config}->{PossibleValues}->{$Value} ) {
+
+            # get readeable value
+            $Value = $Param{DynamicFieldConfig}->{Config}->{PossibleValues}->{$Value};
+
+            # check if translation is possible
+            if (
+                defined $Param{LanguageObject}
+                && $Param{DynamicFieldConfig}->{Config}->{TranslatableValues}
+                )
+            {
+
+                # translate value
+                $Value = $Param{LanguageObject}->Get($Value);
+            }
+        }
+    }
+
+    return $Value;
+}
+
 1;
 
 =back
@@ -831,9 +852,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$$
-
-=cut
